==> theme-bootstrap-1.0.119.tgz: package/src/components/icons/icon-blog-service/icon-blog-service.jsx <==
import React from 'react';

export function IconBlogService() {
  return (
    <svg version="1.1" id="icon-blog-service" xmlns="http://www.w3.org/2000/svg" width="36" height="44" x="0px" y="0px" viewBox="0 0 36 44" style={{ enableBackground: 'new 0 0 36 44' }} xmlSpace="preserve">
      <g>
        <g>
          <path className="st0" fill="#242739" d="M36,4v29L26,43H3c-1.7,0-3-1.3-3-3V4c0-1.7,1.3-3,3-3h30C34.7,1,36,2.3,36,4z" />
          <linearGradient id="icon-blog-service-SVGID_1_" gradientUnits="userSpaceOnUse" x1="-1.6385" y1="44.1814" x2="25.8515" y2="15.9314" gradientTransform="matrix(1 0 0 -1 0 46)">
            <stop offset="0" style={{ stopColor: '#FFFFFF' }} />
            <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
          </linearGradient>
          <path className="st1" fill="url(#icon-blog-service-SVGID_1_)" opacity="0.3" d="M36,4v29L26,43H3c-1.7,0-3-1.3-3-3V4c0-1.7,1.3-3,3-3h30C34.7,1,36,2.3,36,4z" />
          <path className="st2" fill="#12E083" d="M36,33L26,43v-7c0-1.7,1.3-3,3-3H36z" />
          <path
            className="st3"
            fill="#FFFFFF"
            d="M12.7,11.4v-0.2c-0.1-0.8-0.8-1.4-1.6-1.3c-0.8-0.1-1.5,0.5-1.6,1.3c0,0.3,0.2,0.7,0.5,0.8
            c0.4,0.2,0.8,0.4,1.3,0.5c0.2,0,0.4,0.1,0.6,0.1c1,0.2,1.9,0.6,2.7,1.1l0.2,0.1c0.8,0.7,1.2,1.7,1.2,2.8c0,1.2-0.5,2.3-1.4,3
            c-1,0.8-2.2,1.2-3.4,1.2c-1.2,0-2.4-0.4-3.4-1.2c-0.9-0.7-1.4-1.8-1.5-3v-0.2h3.3v0.2c0.1,0.8,0.8,1.4,1.6,1.3
            c0.8,0.1,1.5-0.5,1.6-1.3c0-0.3-0.2-0.7-0.5-0.8c-0.4-0.2-0.8-0.4-1.3-0.5l-0.6-0.1c-1-0.2-1.9-0.5-2.7-1.1L7.6,14
            c-0.8-0.7-1.3-1.8-1.3-2.9c0-1.2,0.5-2.3,1.4-3C8.7,7.4,9.9,7,11.1,7c1.2,0,2.5,0.4,3.4,1.2c0.9,0.7,1.4,1.8,1.4,3v0.2L12.7,11.4z"
          />
          <path className="st4" fill="#A7A8B0" d="M7,31h15c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1H7c-0.6,0-1-0.4-1-1l0,0C6,31.4,6.4,31,7,31z" />
          <path className="st4" fill="#A7A8B0" d="M7,25h22c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1H7c-0.6,0-1-0.4-1-1l0,0C6,25.4,6.4,25,7,25z" />
          <path className="st4" fill="#A7A8B0" d="M21,11h8c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1h-8c-0.6,0-1-0.4-1-1l0,0C20,11.4,20.4,11,21,11z" />
          <path className="st4" fill="#A7A8B0" d="M21,17h8c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1h-8c-0.6,0-1-0.4-1-1l0,0C20,17.4,20.4,17,21,17z" />
        </g>
      </g>
    </svg>
  );
}

==> theme-bootstrap-2.0.16.tgz: package/src/components/icons/icon-blog-service/icon-blog-service.jsx <==
import React from 'react';
import colors from '../../../theme/js/color-variables';

export function IconBlogService() {
  return (
    <svg version="1.1" id="icon-blog-service" xmlns="http://www.w3.org/2000/svg" width="36" height="44" x="0px" y="0px" viewBox="0 0 36 44" style={{ enableBackground: 'new 0 0 36 44' }} xmlSpace="preserve">
      <g>
        <g>
          <path className="st0" fill="#242739" d="M36,4v29L26,43H3c-1.7,0-3-1.3-3-3V4c0-1.7,1.3-3,3-3h30C34.7,1,36,2.3,36,4z" />
          <linearGradient id="icon-blog-service-SVGID_1_" gradientUnits="userSpaceOnUse" x1="-1.6385" y1="44.1814" x2="25.8515" y2="15.9314" gradientTransform="matrix(1 0 0 -1 0 46)">
            <stop offset="0" style={{ stopColor: '#FFFFFF' }} />
            <stop offset="1" style={{ stopColor: '#FFFFFF', stopOpacity: 0 }} />
          </linearGradient>
          <path className="st1" fill="url(#icon-blog-service-SVGID_1_)" opacity="0.3" d="M36,4v29L26,43H3c-1.7,0-3-1.3-3-3V4c0-1.7,1.3-3,3-3h30C34.7,1,36,2.3,36,4z" />
          <path className="st2" fill={colors.greenG30} d="M36,33L26,43v-7c0-1.7,1.3-3,3-3H36z" />
          <path
            className="st3"
            fill="#FFFFFF"
            d="M12.7,11.4v-0.2c-0.1-0.8-0.8-1.4-1.6-1.3c-0.8-0.1-1.5,0.5-1.6,1.3c0,0.3,0.2,0.7,0.5,0.8
            c0.4,0.2,0.8,0.4,1.3,0.5c0.2,0,0.4,0.1,0.6,0.1c1,0.2,1.9,0.6,2.7,1.1l0.2,0.1c0.8,0.7,1.2,1.7,1.2,2.8c0,1.2-0.5,2.3-1.4,3
            c-1,0.8-2.2,1.2-3.4,1.2c-1.2,0-2.4-0.4-3.4-1.2c-0.9-0.7-1.4-1.8-1.5-3v-0.2h3.3v0.2c0.1,0.8,0.8,1.4,1.6,1.3
            c0.8,0.1,1.5-0.5,1.6-1.3c0-0.3-0.2-0.7-0.5-0.8c-0.4-0.2-0.8-0.4-1.3-0.5l-0.6-0.1c-1-0.2-1.9-0.5-2.7-1.1L7.6,14
            c-0.8-0.7-1.3-1.8-1.3-2.9c0-1.2,0.5-2.3,1.4-3C8.7,7.4,9.9,7,11.1,7c1.2,0,2.5,0.4,3.4,1.2c0.9,0.7,1.4,1.8,1.4,3v0.2L12.7,11.4z"
          />
          <path className="st4" fill="#A7A8B0" d="M7,31h15c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1H7c-0.6,0-1-0.4-1-1l0,0C6,31.4,6.4,31,7,31z" />
          <path className="st4" fill="#A7A8B0" d="M7,25h22c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1H7c-0.6,0-1-0.4-1-1l0,0C6,25.4,6.4,25,7,25z" />
          <path className="st4" fill="#A7A8B0" d="M21,11h8c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1h-8c-0.6,0-1-0.4-1-1l0,0C20,11.4,20.4,11,21,11z" />
          <path className="st4" fill="#A7A8B0" d="M21,17h8c0.6,0,1,0.4,1,1l0,0c0,0.6-0.4,1-1,1h-8c-0.6,0-1-0.4-1-1l0,0C20,17.4,20.4,17,21,17z" />
        </g>
      </g>
    </svg>
  );
}
